#!/bin/bash
# hark-ros に対して debuildコマンドによるdebパッケージの作成を行う
# 本来のdebuildは、環境変数を削除してしまうので
# このスクリプトにより、hark-rosに必要な環境変数を付加している
# configureやmakefileの中で、明示的に環境変数を設定しても、debuildのサブプロセスである限り無効である。
# ROS_PACKAGE_PATHは、環境により適宜設定を行うする必要がある。

ROSDISTRO="$1"
# auto detect by variable ROS_DISTRO
if [ "$ROSDISTRO" = -a ]; then
	ROSDISTRO=$ROS_DISTRO
fi

case "$ROSDISTRO" in
	indigo)
		debuild \
		 -e ROS_ROOT=${ROS_ROOT}\
		 -e PATH=${ROS_ROOT}/bin:${PATH} \
		 -e ROS_PACKAGE_PATH=/opt/ros/${ROSDISTRO}/share:/opt/ros/${ROSDISTRO}/stacks \
		 -e LD_LIBRARY_PATH=/opt/ros/${ROSDISTRO}/lib 
	;;

	hydro|groovy|fuerte)	
		#ROS_ROOT=/opt/ros/${ROSDISTRO}/share/ros
		#PATH=${ROS_ROOT}/bin:${PATH}
		#PYTHONPATH=${ROS_ROOT}/core/roslib/src:${PYTHONPATH}
		#ROS_PACKAGE_PATH=${ROS_PACKAGE_PATH}:/opt/ros/${ROSDISTRO}/stacks
		#LD_LIBRARY_PATH=/opt/ros/${ROSDISTRO}/lib
		
		# --preserve-envvar PATH \
		debuild \
		 -e ROS_ROOT=${ROS_ROOT}\
		 -e PATH=${ROS_ROOT}/bin:${PATH} \
		 -e PYTHONPATH=${ROS_ROOT}/core/roslib/src:${PYTHONPATH} \
		 -e ROS_PACKAGE_PATH=/opt/ros/${ROSDISTRO}/share:/opt/ros/${ROSDISTRO}/stacks:${HOME}/ros/hark/hark_common_msgs/hark_msgs:${HOME}/ros/hark/hark_common_msgs/hark_params \
		 -e LD_LIBRARY_PATH=/opt/ros/${ROSDISTRO}/lib
	;;

	cturtle)
		#ROS_ROOT=/opt/ros/${ROSDISTRO}/ros
		#PATH=${ROS_ROOT}/bin:${PATH}
		#PYTHONPATH=${ROS_ROOT}/core/roslib/src:${PYTHONPATH}
		#ROS_PACKAGE_PATH=/opt/ros/${ROSDISTRO}/stacks
		
		# --preserve-envvar PATH \
		debuild \
		 -e ROS_ROOT=${ROS_ROOT}\
		 -e PATH=${ROS_ROOT}/bin:${PATH} \
		 -e PYTHONPATH=${ROS_ROOT}/core/roslib/src:${PYTHONPATH} \
		 -e ROS_PACKAGE_PATH=/opt/ros/${ROSDISTRO}/stacks:`pwd`/hark_msgs:`pwd`/hark_params
	;;
	
	""|*)
		echo "Argument error:" 1>&2
		echo "  ROS distro can only be one of: indigo, hydro, groovy, fuerte, cturtle" 1>&2
		exit 1
	;;
esac
